@@ -858,7 +858,7 @@ var roleListMixin = {
             vm.unregistered = {slug: "", email: "", full_name: ""};
             vm.profileRequestDone = false;
             if( vm.$refs.typeahead ) {
-                vm.$refs.typeahead.clear();
+                vm.$refs.typeahead.reset();
             }
             vm.$emit('invite-completed');
         },
@@ -866,6 +866,9 @@ var roleListMixin = {
             var vm = this;
             vm.newProfile = {slug: "", email: "", full_name: ""};
             vm.inNewProfileFlow = false;
+            if( vm.$refs.typeahead ) {
+                vm.$refs.typeahead.reset();
+            }
             vm.$emit('create-completed');
         },
         create: function() { // create a new profile to be owned by user.
@@ -915,6 +918,12 @@ var roleListMixin = {
                 vm.unregistered = item;
                 vm.profileRequestDone = false;
                 vm.submit();
+            } else {
+                vm.newProfile.full_name = vm.$refs.typeahead.query;
+                vm.newProfile.email = vm.requestUser ? (
+                    vm.requestUser.email ? vm.requestUser.email : vm.requestUser) : "";
+//                vm.newProfile.slug = "XXX";
+                vm.create();
             }
         },
         refresh: function() {
@@ -946,17 +955,35 @@ var roleListMixin = {
                 vm.$emit('remove-completed');
             });
         },
+        reset: function() {
+            var vm = this;
+            vm.candidateId = "";
+            vm.unregistered = {slug: "", email: "", full_name: ""};
+            vm.newProfile = {slug: "", email: "", full_name: ""};
+            vm.profileRequestDone = false;
+            vm.inNewProfileFlow = false;
+            if( vm.$refs.typeahead ) {
+                vm.$refs.typeahead.reset();
+                vm.$refs.typeahead.$refs.input.focus();
+            }
+        },
         save: function(item){ // user-typeahead @item-save="save"
             this._addRole(item);
         },
         submit: function() {
             var vm = this;
-            if( vm.unregistered.slug || vm.unregistered.email) {
-                this._addRole(vm.unregistered, vm.profileRequestDone);
+            if( vm.newProfile.full_name || vm.newProfile.full_name ||
+                vm.newProfile.email ) {
+                vm.create();
             } else {
-                this._addRole((vm.$refs.account && vm.$refs.account.query) ?
-                    vm.$refs.account.query : vm.candidateId,
-                    vm.profileRequestDone);
+                if( vm.unregistered.slug || vm.unregistered.email) {
+                    this._addRole(vm.unregistered, vm.profileRequestDone);
+                } else {
+                    this._addRole(
+                        (vm.$refs.typeahead && vm.$refs.typeahead.query) ?
+                            vm.$refs.typeahead.query : vm.candidateId,
+                        vm.profileRequestDone);
+                }
             }
         },
         updateParams: function(){ // internal
@@ -1556,7 +1583,7 @@ Vue.component('metrics-charts', {
                     location: table.location,
                     unit: unit,
                     scale: scale,
-                    data: resp.table
+                    data: resp.results
                 }
                 vm.convertDatetime(tableData.data, vm.timezone === 'utc');
                 for( var idx = 0; idx < vm.tables.length; ++idx ) {
@@ -1966,6 +1993,21 @@ Vue.component('import-transaction', {
             }
         },
     },
+    computed: {
+        _created_at: {
+            get: function() {
+                return this.asDateInputField(this.entry.created_at);
+            },
+            set: function(newVal) {
+                if( newVal ) {
+                    // The setter might be call with `newVal === null`
+                    // when the date is incorrect (ex: 09/31/2022).
+                    this.$set(this.entry, 'created_at',
+                        this.asDateISOString(newVal));
+                }
+            }
+        },
+    }
 });
 
 
@@ -2773,13 +2815,27 @@ Vue.component('unengaged-subscribers', {
 
 Vue.component('search-profile', {
     mixins: [
-        itemListMixin
+        typeAheadMixin
     ],
     data: function() {
         return {
             url: this.$urls.provider.api_accounts,
         }
-    },
+    }
+});
+
+
+Vue.component('subscription-typeahead', {
+    mixins: [
+        typeAheadMixin
+    ],
+    methods: {
+        onHit: function onHit(newItem) {
+            var vm = this;
+            vm.$emit('selectitem', newItem);
+            vm.clear();
+        }
+    }
 });
 
 
@@ -2818,8 +2874,8 @@ Vue.component('monthly-revenue', {
         amount: function(){
             var amount = 0;
             if(this.itemLoaded){
-                this.item.table.forEach(function(e){
-                    if(e.key === 'Total Sales'){
+                this.item.results.forEach(function(e){
+                    if(e.slug === 'Total Sales'){
                         // get MRR from last month
                         amount = e.values[e.values.length - 2][1];
                     }
