@@ -437,7 +437,7 @@
                     formData.append("file", file.get(0).files[0]);
                     $.ajax({
                         type: "POST",
-                        url: "/api/cart/" + plan + "/upload/",
+                        url:self.options.saas_api_cart + "/" + plan + "/upload",
                         beforeSend: function(xhr) {
                             xhr.setRequestHeader(
                                 "X-CSRFToken", self._getCSRFToken());
@@ -542,20 +542,16 @@
             }
         },
 
-        createLineMessage: function(data) {
-            return data.full_name + " (" + data.sync_on + ")";
-        },
-
         insertLine: function(data) {
-            var msg = this.createLineMessage(data);
-            var prevLine = this.element.find("tbody[data-plan='" +
-                data.plan + "'] .invoice-item").last();
+            var msg = data.detail;
+            var planSlug = data.plan.slug;
+            var prevLine = this.element.find(
+                "tbody[data-plan='" + planSlug + "'] .invoice-item").last();
             var newLine = prevLine.clone();
             var clonedNode = newLine.children("td.line-descr");
 
             prevLine.removeClass("alert alert-info");
-            var txt = clonedNode.text().split(', for');
-            clonedNode.text(txt[0] + ", for " + msg);
+            clonedNode.text(msg);
             newLine.insertAfter(prevLine);
             newLine.addClass("alert alert-info");
 
@@ -563,9 +559,10 @@
         },
 
         updateLine: function(data) {
-            var msg = this.createLineMessage(data);
-            var prevLine = this.element.find("tbody[data-plan='" +
-                data.plan + "'] .invoice-item")
+            var msg =  data.detail;
+            var planSlug = data.plan.slug;
+            var prevLine = this.element.find(
+                "tbody[data-plan='" + planSlug + "'] .invoice-item");
             var dup = null;
             prevLine.each(function(i){
                 var $t = $(this);
@@ -580,9 +577,7 @@
             }
             var newLine = prevLine;
             var descrNode = newLine.children("td.line-descr");
-
-            var txt = descrNode.text().split(', for');
-            descrNode.text(txt[0] + ", for " + msg);
+            descrNode.text(msg);
             newLine.addClass("alert alert-info");
 
             this.updateTotalAmount();
@@ -596,7 +591,7 @@
 
     $.fn.invoice.defaults = {
         currency_unit: "usd",
-        saas_api_cart: "/api/cart/"
+        saas_api_cart: "/api/cart"
     };
 
    /** redeem a ``Coupon``.
@@ -716,7 +711,7 @@
         "use strict";
         var self = this;
         $.ajax({ type: "POST",
-                 url: self.options.saas_api_plan + "/",
+                 url: self.options.saas_api_plan,
                  beforeSend: function(xhr) {
                      xhr.setRequestHeader("X-CSRFToken", self._getCSRFToken());
                  },
@@ -739,7 +734,7 @@
         "use strict";
         var self = this;
         $.ajax({ type: "PUT",
-                 url: self.options.saas_api_plan + "/" + self.id + "/",
+                 url: self.options.saas_api_plan + "/" + self.id,
                  beforeSend: function(xhr) {
                      xhr.setRequestHeader("X-CSRFToken", self._getCSRFToken());
                  },
@@ -755,7 +750,7 @@
         "use strict";
         var self = this;
         $.ajax({ type: "DELETE",
-                 url: self.options.saas_api_plan + "/" + self.id + "/",
+                 url: self.options.saas_api_plan + "/" + self.id,
                  beforeSend: function(xhr) {
                      xhr.setRequestHeader("X-CSRFToken", self._getCSRFToken());
                  },
@@ -774,7 +769,7 @@
         "use strict";
         var self = this;
         $.ajax({ type: "GET",
-                 url: self.options.saas_api_plan + "/" + self.id + "/",
+                 url: self.options.saas_api_plan + "/" + self.id,
                  success: successFunction
                });
       },
@@ -786,7 +781,7 @@
           var self = this;
           var button = self.element.find(".activate");
           $.ajax({type: "PUT",
-                 url: self.options.saas_api_plan + "/" + self.id + "/",
+                 url: self.options.saas_api_plan + "/" + self.id,
                  beforeSend: function(xhr) {
                      xhr.setRequestHeader("X-CSRFToken", self._getCSRFToken());
                  },
