@@ -1,5 +1,5 @@
-# -*- coding: utf-8 -*-
-# Copyright (c) 2021, DjaoDjin inc.
+# coding: utf-8
+# Copyright (c) 2023, DjaoDjin inc.
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -37,7 +37,7 @@ from django.utils.timezone import utc
 from ..compat import gettext_lazy as _, six
 from ..decorators import fail_direct, _valid_manager
 from ..humanize import as_money, as_percentage
-from ..mixins import as_html_description, product_url as utils_product_url
+from ..mixins import as_html_description
 from ..models import Plan, Price, Subscription, get_broker
 from ..utils import get_organization_model
 
@@ -73,13 +73,18 @@ def describe(transaction):
         descr = transaction['description']  # Serializers have already run
                                             # `as_html_description`.
     except (TypeError, KeyError):
-        descr = as_html_description(transaction)
+        # We would need the request here but we don;t have it
+        # so we set `force_links` to `True` in order to generate
+        # URL paths anyway.
+        descr = as_html_description(transaction, force_links=True)
     return mark_safe(descr)
 
 
+# `describe_no_links` is used on the checkout page to show plans
+# that will be subscribed to.
 @register.filter(needs_autoescape=False)
 def describe_no_links(transaction):
-    return mark_safe(as_html_description(transaction, active_links=False))
+    return mark_safe(as_html_description(transaction))
 
 
 @register.filter()
@@ -225,11 +230,6 @@ def products(subscriptions):
     return []
 
 
-@register.filter(needs_autoescape=False)
-def product_url(organization, subscriber=None):
-    return utils_product_url(organization, subscriber)
-
-
 @register.filter()
 def short_date(val):
     if isinstance(val, datetime):
