@@ -1,4 +1,4 @@
-# Copyright (c) 2020, DjaoDjin inc.
+# Copyright (c) 2022, DjaoDjin inc.
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -26,19 +26,17 @@
 URLs for the cart API of djaodjin saas.
 """
 
-from django.conf.urls import url
-
 from ...api.billing import (CartItemAPIView, CartItemUploadAPIView,
                             CouponRedeemAPIView)
 from ...api.plans import PricingAPIView
-from ...settings import ACCT_REGEX
+from ...compat import path
 
 urlpatterns = [
-    url(r'^pricing/',
+    path('pricing',
         PricingAPIView.as_view(), name='saas_api_pricing'),
-    url(r'^cart/redeem/',
+    path('cart/redeem',
         CouponRedeemAPIView.as_view(), name='saas_api_redeem_coupon'),
-    url(r'^cart/(?P<plan>%s)/upload/' % ACCT_REGEX,
+    path('cart/<slug:plan>/upload',
         CartItemUploadAPIView.as_view(), name='saas_api_cart_upload'),
-    url(r'^cart/', CartItemAPIView.as_view(), name='saas_api_cart')
+    path('cart', CartItemAPIView.as_view(), name='saas_api_cart')
 ]
