@@ -116,13 +116,13 @@ class LifeTimeValueMetricsView(ProviderMixin, TemplateView):
     def get_context_data(self, **kwargs):
         context = super(LifeTimeValueMetricsView, self).get_context_data(
             **kwargs)
-        urls = {
-            'metrics_lifetimevalue_download': reverse(
+        update_context_urls(context, {
+            'download': reverse(
                 'saas_metrics_lifetimevalue_download', args=(self.provider,)),
             'provider': {
                 'api_metrics_lifetimevalue': reverse(
-                    'saas_api_metrics_lifetimevalue', args=(self.provider,))}}
-        update_context_urls(context, urls)
+                    'saas_api_metrics_lifetimevalue', args=(self.provider,))}
+        })
         return context
 
 
@@ -130,6 +130,8 @@ class LifeTimeValueDownloadView(LifetimeValueMetricMixin, CSVDownloadView):
     """
     Export customers lifetime value as a CSV file.
     """
+    basename = 'lifetimevalue'
+
     headings = ['Profile', 'Since', 'Ends at',
         'Contract value', 'Cash payments', 'Deferred revenue']
 
@@ -187,8 +189,9 @@ class PlansMetricsView(ProviderMixin, TemplateView):
     To edit the layout of this page, create a local \
     ``saas/metrics/plans.html`` (`example <https://github.com/djaodjin\
 /djaodjin-saas/tree/master/saas/templates/saas/metrics/plans.html>`__).
-    The page will typically call back
-    :ref:`/api/metrics/:organization/plans/ <api_metrics_plans>`
+    The page will typically call
+    `/api/metrics/{profile}/plans <https://www.djaodjin.com/docs/\
+reference/djaoapp/latest/api/#listPlanMetric>`__
     to fetch the 12 month trailing performance in terms of subscribers
     of the plans of a provider.
 
@@ -233,14 +236,17 @@ class RevenueMetricsView(MetricsMixin, TemplateView):
     ``saas/metrics/revenue.html`` (`example <https://github.com/djaodjin\
 /djaodjin-saas/tree/master/saas/templates/saas/metrics/revenue.html>`__).
 
-    The page will typically call back
-    :ref:`/api/metrics/:organization/funds/ <api_metrics_funds>`
+    The page will typically call
+    `/api/metrics/{profile}/funds <https://www.djaodjin.com/docs/\
+reference/djaoapp/latest/api/#listRevenueMetric>`
     to fetch the 12 month trailing cash flow table, and/or
-    :ref:`/api/metrics/:organization/balances/ <api_metrics_balances>`
+    `/api/metrics/{profile}/balances <https://www.djaodjin.com/docs/\
+reference/djaoapp/latest/api/#listBalances>`__
     to fetch the 12 month trailing receivable/backlog/income revenue.
 
-    The example page also calls back
-    :ref:`/api/metrics/:organization/customers/ <api_metrics_customers>`
+    The example page also calls
+    `/api/metrics/{profile}/customers <https://www.djaodjin.com/docs/\
+reference/djaoapp/latest/api/#listCustomerMetric>`__
     to fetch the distinct number of customers that generated the cash
     transactions.
 
@@ -259,19 +265,27 @@ class RevenueMetricsView(MetricsMixin, TemplateView):
             unit = a_receivable.orig_unit
         context.update({
             "title": "Sales",
-            "tables": json.dumps(
-                [{"key": "cash",
-                        "title": "Amounts",
-                        "unit": unit,
-                        "location": reverse('saas_api_revenue',
-                            args=(self.organization,))},
-                       {"key": "customer",
-                        "title": "Customers",
-                        "location": reverse('saas_api_customer',
-                            args=(self.organization,))},
-                       {"key": "balances",
-                        "title": "Balances",
-                        "unit": unit,
-                        "location": reverse('saas_api_balances',
-                            args=(self.organization,))}])})
+            "tables": json.dumps([{
+                "key": "cash",
+                "title": "Amounts",
+                "unit": unit,
+                "location": reverse('saas_api_revenue',
+                    args=(self.organization,))
+            }, {
+                "key": "balances",
+                "title": "Balances",
+                "unit": unit,
+                "location": reverse('saas_api_balances',
+                    args=(self.organization,))
+            }, {
+                "key": "customer",
+                "title": "Customers",
+                "location": reverse('saas_api_customer',
+                    args=(self.organization,))
+            }, {
+                "key": "plan",
+                "title": "Active subscribers",
+                "location": reverse('saas_api_metrics_plans',
+                    args=(self.organization,))
+            }])})
         return context
